All Classes and Interfaces
Class
Description
Abstract implementation of the base
ConnectionRequestEvent.Abstract implementation of the base
ConnectionStatusEvent.Abstract implementation of the base
LifecycleRequestEvent.The
AbstractLifecycleStatusEvent event is the base implementation for
the LifecycleStatusEvent.An
ConnectionStatus denoting accomplished closing.Implementation of the
ConnectionStatusEvent for
ConnectionStatus.CLOSED.Implementation of the
ConnectionRequestEvent for
ConnectionRequest.CLOSE.An
ConnectionRequest event denoting a close request.The
ComponentEvent is the base event for component related signals.The
ConnectionEvent is the base event for connection related signals.An observer for listening to
ConnectionEvent instances.An observer for listening to
ConnectionRequestEvent instances.Provides an accessor for a
ConnectionRequest property.Provides a mutator for a
ConnectionRequest property.Provides a
ConnectionRequest property.The
ConnectionRequestEvent represents a ConnectionRequest and
might be vetoed by (depending on the firing observable) throwing a
VetoException or VetoException.VetoRuntimeException by the according
Observer.The
ConnectionStatusEvent indicates the ConnectionStatus for
a component.An
LifecycleStatusEvent denoting accomplished destroying.Implementation of the
LifecycleStatusEvent for
LifecycleStatus.DESTROYED.Implementation of the
LifecycleRequestEvent for
LifecycleRequest.DESTROY.An
LifecycleRequestEvent event denoting a destroy request.An
LifecycleStatusEvent denoting accomplished initialization.Implementation of the
LifecycleStatusEvent for
LifecycleStatus.INITIALIZED.Implementation of the
LifecycleRequestEvent for
LifecycleRequest.INITIALIZE.An
LifecycleRequestEvent event denoting an initialize request.The
LifecycleEvent is the base event for connection related signals.The
LifecycleRequestEvent represents a LifecycleRequest and
might be vetoed by (depending on the firing observable) throwing a
VetoException or VetoException.VetoRuntimeException by the according
Observer.An observer for listening to
LifecycleRequestEvent instances.The
LifecycleStatusEvent indicates the LifecycleStatus for a
component.The
LifecycleStatusObserver is signaled upon
LifecycleStatusEvent events.The
ObservableLifecycleRequestMachine extends the
LifecycleMachine with request ActionEvent functionality which
can be vetoed.
The
ObservableLifecycleStatusMachine extends the
LifecycleMachine with life-cycle ActionEvent functionality
which can be vetoed, such running through several stages from getting started
till being destroyed.An
ConnectionStatus denoting accomplished opening.Implementation of the
ConnectionStatusEvent for
ConnectionStatus.OPENED.Implementation of the
ConnectionRequestEvent for
ConnectionRequest.OPEN.An
ConnectionRequest event denoting an open request.An
LifecycleStatusEvent denoting accomplished pausing.Implementation of the
LifecycleStatusEvent for
LifecycleStatus.PAUSED.Implementation of the
LifecycleRequestEvent for
LifecycleRequest.PAUSE.An
LifecycleRequestEvent event denoting a pause request.An
LifecycleStatusEvent denoting accomplished resuming.Implementation of the
LifecycleStatusEvent for
LifecycleStatus.STARTED.Implementation of the
LifecycleRequestEvent for
LifecycleRequest.RESUME.An
LifecycleRequestEvent event denoting a resume request.An
LifecycleStatusEvent denoting accomplished starting.Implementation of the
LifecycleStatusEvent for
LifecycleStatus.STARTED.Implementation of the
LifecycleRequestEvent for
LifecycleRequest.START.An
LifecycleRequestEvent event denoting a start request.An
LifecycleStatusEvent denoting accomplished stopping.Implementation of the
LifecycleRequestEvent for
LifecycleRequest.STOP.Implementation of the
LifecycleStatusEvent for
LifecycleStatus.STOPPED.An
LifecycleRequestEvent event denoting a stop request.