Interface ComponentEvent<A,SRC>
- Type Parameters:
A- The type of the action stored in the event.SRC- The type of the source in question.
- All Superinterfaces:
ActionAccessor<A>, ActionEvent<A,SRC>, Event<SRC>, SourceAccessor<SRC>
- All Known Subinterfaces:
ClosedAccomplishedEvent<SRC>, CloseRequestedEvent<SRC>, ConnectionEvent<A,SRC>, ConnectionRequestEvent<SRC>, ConnectionStatusEvent<SRC>, DestroyAccomplishedEvent<SRC>, DestroyRequestedEvent<SRC>, InitializeAccomplishedEvent<SRC>, InitializeRequestedEvent<SRC>, LifecycleEvent<A, SRC>, LifecycleRequestEvent<SRC>, LifecycleStatusEvent<SRC>, OpenAccomplishedEvent<SRC>, OpenRequestedEvent<SRC>, PauseAccomplishedEvent<SRC>, PauseRequestedEvent<SRC>, ResumeAccomplishedEvent<SRC>, ResumeRequestedEvent<SRC>, StartAccomplishedEvent<SRC>, StartRequestedEvent<SRC>, StopAccomplishedEvent<SRC>, StopRequestedEvent<SRC>
- All Known Implementing Classes:
AbstractConnectionRequestEvent, AbstractConnectionStatusEvent, AbstractLifecycleRequestEvent, AbstractLifecycleStatusEvent, ClosedEvent, CloseEvent, DestroyedEvent, DestroyEvent, InitializedEvent, InitializeEvent, OpenedEvent, OpenEvent, PausedEvent, PauseEvent, ResumedEvent, ResumeEvent, StartedEvent, StartEvent, StopEvent, StoppedEvent
The
ComponentEvent is the base event for component related signals.-
Nested Class Summary
Nested classes/interfaces inherited from interface ActionAccessor
ActionAccessor.ActionBuilder<A,B>, ActionAccessor.ActionMutator<A>, ActionAccessor.ActionProperty<A> Nested classes/interfaces inherited from interface SourceAccessor
SourceAccessor.SourceBuilder<SRC,B>, SourceAccessor.SourceMutator<SRC>, SourceAccessor.SourceProperty<SRC> -
Method Summary
Methods inherited from interface ActionAccessor
getActionMethods inherited from interface SourceAccessor
getSource