Interface ConnectionObserver.ConnectionRequestObserver<SRC>
- Type Parameters:
SRC- The type of the source in question.
- All Superinterfaces:
ConnectionObserver<SRC>, Observer<ConnectionEvent<?,SRC>>
- Enclosing interface:
ConnectionObserver<SRC>
public static interface ConnectionObserver.ConnectionRequestObserver<SRC>
extends ConnectionObserver<SRC>
An observer for listening to
ConnectionRequestEvent instances.-
Nested Class Summary
Nested classes/interfaces inherited from interface ConnectionObserver
ConnectionObserver.ConnectionRequestObserver<SRC> -
Method Summary
Modifier and TypeMethodDescriptionvoidonCloseEvent(CloseEvent<SRC> aEvent) In case a device is to be closed, then theCloseEventevent is fired.voidonOpenEvent(OpenEvent<SRC> aEvent) In case a device is to be opened, then theOpenEventevent is fired.Methods inherited from interface ConnectionObserver
onClosedEvent, onOpendEvent
-
Method Details
-
onOpenEvent
In case a device is to be opened, then theOpenEventevent is fired.- Parameters:
aEvent- The accordingOpenEvent.- Throws:
VetoException- the veto exception
-
onCloseEvent
In case a device is to be closed, then theCloseEventevent is fired.- Parameters:
aEvent- The accordingCloseEvent.- Throws:
VetoException- the veto exception
-