Interface GenericLifeCycleRequestObserver<A,INIT extends GenericInitializeEvent<A,META,SRC>,START extends GenericStartEvent<A,META,SRC>,RESUME extends GenericResumeEvent<A,META,SRC>,PAUSE extends GenericPauseEvent<A,META,SRC>,STOP extends GenericStopEvent<A,META,SRC>,DESTROY extends GenericDestroyEvent<A,META,SRC>,META extends org.refcodes.mixin.EventMetaData,SRC>
-
- All Known Subinterfaces:
LifeCycleRequestObserver
public interface GenericLifeCycleRequestObserver<A,INIT extends GenericInitializeEvent<A,META,SRC>,START extends GenericStartEvent<A,META,SRC>,RESUME extends GenericResumeEvent<A,META,SRC>,PAUSE extends GenericPauseEvent<A,META,SRC>,STOP extends GenericStopEvent<A,META,SRC>,DESTROY extends GenericDestroyEvent<A,META,SRC>,META extends org.refcodes.mixin.EventMetaData,SRC>TheGenericLifeCycleRequestObserveris signaled uponGenericLifeCycleRequestEventevents.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidonDestroy(DESTROY aEvent)In case a component is to be initialized, then theGenericDestroyEventevent is fired.voidonInitialize(INIT aEvent)In case a component is to be initialized, then theGenericInitializeEventevent is fired.voidonPause(PAUSE aEvent)In case a component is to be initialized, then theGenericPauseEventevent is fired.voidonResume(RESUME aEvent)In case a component is to be initialized, then theGenericResumeEventevent is fired.voidonStart(START aEvent)In case a component is to be initialized, then theGenericStartEventevent is fired.voidonStop(STOP aEvent)In case a component is to be initialized, then theGenericStopEventevent is fired.
-
-
-
Method Detail
-
onInitialize
void onInitialize(INIT aEvent)
In case a component is to be initialized, then theGenericInitializeEventevent is fired.- Parameters:
aEvent- The accordingGenericInitializeEvent.
-
onStart
void onStart(START aEvent)
In case a component is to be initialized, then theGenericStartEventevent is fired.- Parameters:
aEvent- The accordingGenericStartEvent.
-
onResume
void onResume(RESUME aEvent)
In case a component is to be initialized, then theGenericResumeEventevent is fired.- Parameters:
aEvent- The accordingGenericResumeEvent.
-
onPause
void onPause(PAUSE aEvent)
In case a component is to be initialized, then theGenericPauseEventevent is fired.- Parameters:
aEvent- The accordingGenericPauseEvent.
-
onStop
void onStop(STOP aEvent)
In case a component is to be initialized, then theGenericStopEventevent is fired.- Parameters:
aEvent- The accordingGenericStopEvent.
-
onDestroy
void onDestroy(DESTROY aEvent)
In case a component is to be initialized, then theGenericDestroyEventevent is fired.- Parameters:
aEvent- The accordingGenericDestroyEvent.
-
-