Interface GenericLifecycleRequestObserver<A,INIT extends GenericInitializeEvent<A,META,SRC>,START extends GenericStartEvent<A,META,SRC>,RESUME extends GenericResumeEvent<A,META,SRC>,PAUSE extends GenericPauseEvent<A,META,SRC>,STOP extends GenericStopEvent<A,META,SRC>,DESTROY extends GenericDestroyEvent<A,META,SRC>,META extends org.refcodes.mixin.EventMetaData,SRC>
- All Known Subinterfaces:
LifecycleRequestObserver
public interface GenericLifecycleRequestObserver<A,INIT extends GenericInitializeEvent<A,META,SRC>,START extends GenericStartEvent<A,META,SRC>,RESUME extends GenericResumeEvent<A,META,SRC>,PAUSE extends GenericPauseEvent<A,META,SRC>,STOP extends GenericStopEvent<A,META,SRC>,DESTROY extends GenericDestroyEvent<A,META,SRC>,META extends org.refcodes.mixin.EventMetaData,SRC>
The
GenericLifecycleRequestObserver is signaled upon
GenericLifecycleRequestEvent events.-
Method Summary
Modifier and TypeMethodDescriptionvoidIn case a component is to be initialized, then theGenericDestroyEventevent is fired.voidonInitialize(INIT aEvent) In case a component is to be initialized, then theGenericInitializeEventevent is fired.voidIn case a component is to be initialized, then theGenericPauseEventevent is fired.voidIn case a component is to be initialized, then theGenericResumeEventevent is fired.voidIn case a component is to be initialized, then theGenericStartEventevent is fired.voidIn case a component is to be initialized, then theGenericStopEventevent is fired.
-
Method Details
-
onInitialize
In case a component is to be initialized, then theGenericInitializeEventevent is fired.- Parameters:
aEvent- The accordingGenericInitializeEvent.
-
onStart
In case a component is to be initialized, then theGenericStartEventevent is fired.- Parameters:
aEvent- The accordingGenericStartEvent.
-
onResume
In case a component is to be initialized, then theGenericResumeEventevent is fired.- Parameters:
aEvent- The accordingGenericResumeEvent.
-
onPause
In case a component is to be initialized, then theGenericPauseEventevent is fired.- Parameters:
aEvent- The accordingGenericPauseEvent.
-
onStop
In case a component is to be initialized, then theGenericStopEventevent is fired.- Parameters:
aEvent- The accordingGenericStopEvent.
-
onDestroy
In case a component is to be initialized, then theGenericDestroyEventevent is fired.- Parameters:
aEvent- The accordingGenericDestroyEvent.
-