Interface GenericLifecycleStatusObserver<A,INITED extends GenericInitializedEvent<A,META,SRC>,STARTED extends GenericStartedEvent<A,META,SRC>,RESUMED extends GenericResumedEvent<A,META,SRC>,PAUSED extends GenericPausedEvent<A,META,SRC>,STOPPED extends GenericStoppedEvent<A,META,SRC>,DESTROYED extends GenericDestroyedEvent<A,META,SRC>,META extends org.refcodes.mixin.EventMetaData,SRC>
- All Known Subinterfaces:
LifecycleStatusObserver
public interface GenericLifecycleStatusObserver<A,INITED extends GenericInitializedEvent<A,META,SRC>,STARTED extends GenericStartedEvent<A,META,SRC>,RESUMED extends GenericResumedEvent<A,META,SRC>,PAUSED extends GenericPausedEvent<A,META,SRC>,STOPPED extends GenericStoppedEvent<A,META,SRC>,DESTROYED extends GenericDestroyedEvent<A,META,SRC>,META extends org.refcodes.mixin.EventMetaData,SRC>
The
GenericLifecycleStatusObserver is signaled upon
GenericLifecycleStatusEvent events.-
Method Summary
Modifier and TypeMethodDescriptionvoidonDestroyed(DESTROYED aEvent) In case a component is to be initialized, then theGenericDestroyedEventevent is fired.voidonInitialized(INITED aEvent) In case a component is to be initialized, then theGenericInitializedEventevent is fired.voidIn case a component is to be initialized, then theGenericStartedEventevent is fired.voidIn case a component is to be initialized, then theGenericResumedEventevent is fired.voidIn case a component is to be initialized, then theGenericStartedEventevent is fired.voidIn case a component is to be initialized, then theGenericStoppedEventevent is fired.
-
Method Details
-
onInitialized
In case a component is to be initialized, then theGenericInitializedEventevent is fired.- Parameters:
aEvent- The accordingGenericInitializedEvent.
-
onStarted
In case a component is to be initialized, then theGenericStartedEventevent is fired.- Parameters:
aEvent- The accordingGenericStartedEvent.
-
onResumed
In case a component is to be initialized, then theGenericResumedEventevent is fired.- Parameters:
aEvent- The accordingGenericResumedEvent.
-
onPaused
In case a component is to be initialized, then theGenericStartedEventevent is fired.- Parameters:
aEvent- The accordingGenericStartedEvent.
-
onStopped
In case a component is to be initialized, then theGenericStoppedEventevent is fired.- Parameters:
aEvent- The accordingGenericStoppedEvent.
-
onDestroyed
In case a component is to be initialized, then theGenericDestroyedEventevent is fired.- Parameters:
aEvent- The accordingGenericDestroyedEvent.
-