Interface LifecycleRequestObserver<INIT extends InitializeRequestedEvent<SRC>, START extends StartRequestedEvent<SRC>, RESUME extends ResumeRequestedEvent<SRC>, PAUSE extends PauseRequestedEvent<SRC>, STOP extends StopRequestedEvent<SRC>, DESTROY extends DestroyRequestedEvent<SRC>, META extends org.refcodes.observer.EventMetaData, SRC>

Type Parameters:
INIT - the generic type
START - the generic type
RESUME - the generic type
PAUSE - the generic type
STOP - the generic type
DESTROY - the generic type
META - the generic type
SRC - The source of the events consumed by the LifecycleRequestObserver.

public interface LifecycleRequestObserver<INIT extends InitializeRequestedEvent<SRC>, START extends StartRequestedEvent<SRC>, RESUME extends ResumeRequestedEvent<SRC>, PAUSE extends PauseRequestedEvent<SRC>, STOP extends StopRequestedEvent<SRC>, DESTROY extends DestroyRequestedEvent<SRC>, META extends org.refcodes.observer.EventMetaData, SRC>
An observer for listening to LifecycleRequestEvent instances.
  • Method Summary

    Modifier and Type
    Method
    Description
    void
    In case a component is to be initialized, then the DestroyEvent event is fired.
    void
    In case a component is to be initialized, then the InitializeEvent event is fired.
    void
    onPause(PAUSE aEvent)
    In case a component is to be initialized, then the PauseEvent event is fired.
    void
    onResume(RESUME aEvent)
    In case a component is to be initialized, then the ResumeEvent event is fired.
    void
    onStart(START aEvent)
    In case a component is to be initialized, then the StartEvent event is fired.
    void
    onStop(STOP aEvent)
    In case a component is to be initialized, then the StopEvent event is fired.
  • Method Details

    • onInitialize

      void onInitialize(INIT aEvent)
      In case a component is to be initialized, then the InitializeEvent event is fired.
      Parameters:
      aEvent - The according InitializeEvent.
    • onStart

      void onStart(START aEvent)
      In case a component is to be initialized, then the StartEvent event is fired.
      Parameters:
      aEvent - The according StartEvent.
    • onResume

      void onResume(RESUME aEvent)
      In case a component is to be initialized, then the ResumeEvent event is fired.
      Parameters:
      aEvent - The according ResumeEvent.
    • onPause

      void onPause(PAUSE aEvent)
      In case a component is to be initialized, then the PauseEvent event is fired.
      Parameters:
      aEvent - The according PauseEvent.
    • onStop

      void onStop(STOP aEvent)
      In case a component is to be initialized, then the StopEvent event is fired.
      Parameters:
      aEvent - The according StopEvent.
    • onDestroy

      void onDestroy(DESTROY aEvent)
      In case a component is to be initialized, then the DestroyEvent event is fired.
      Parameters:
      aEvent - The according DestroyEvent.