Interface LifecycleStatusObserver<INITED extends InitializeAccomplishedEvent<SRC>,STARTED extends StartAccomplishedEvent<SRC>,RESUMED extends ResumeAccomplishedEvent<SRC>,PAUSED extends PauseAccomplishedEvent<SRC>,STOPPED extends StopAccomplishedEvent<SRC>,DESTROYED extends DestroyAccomplishedEvent<SRC>,META extends org.refcodes.observer.EventMetaData,SRC>
- Type Parameters:
INITED- the generic typeSTARTED- the generic typeRESUMED- the generic typePAUSED- the generic typeSTOPPED- the generic typeDESTROYED- the generic typeMETA- the generic typeSRC- the generic type
public interface LifecycleStatusObserver<INITED extends InitializeAccomplishedEvent<SRC>,STARTED extends StartAccomplishedEvent<SRC>,RESUMED extends ResumeAccomplishedEvent<SRC>,PAUSED extends PauseAccomplishedEvent<SRC>,STOPPED extends StopAccomplishedEvent<SRC>,DESTROYED extends DestroyAccomplishedEvent<SRC>,META extends org.refcodes.observer.EventMetaData,SRC>
The
LifecycleStatusObserver is signaled upon
LifecycleStatusEvent events.-
Method Summary
Modifier and TypeMethodDescriptionvoidonDestroyed(DESTROYED aEvent) In case a component is to be initialized, then theDestroyedEventevent is fired.voidonInitialized(INITED aEvent) In case a component is to be initialized, then theInitializedEventevent is fired.voidIn case a component is to be initialized, then theStartedEventevent is fired.voidIn case a component is to be initialized, then theResumedEventevent is fired.voidIn case a component is to be initialized, then theStartedEventevent is fired.voidIn case a component is to be initialized, then theStoppedEventevent is fired.
-
Method Details
-
onInitialized
In case a component is to be initialized, then theInitializedEventevent is fired.- Parameters:
aEvent- The accordingInitializedEvent.
-
onStarted
In case a component is to be initialized, then theStartedEventevent is fired.- Parameters:
aEvent- The accordingStartedEvent.
-
onResumed
In case a component is to be initialized, then theResumedEventevent is fired.- Parameters:
aEvent- The accordingResumedEvent.
-
onPaused
In case a component is to be initialized, then theStartedEventevent is fired.- Parameters:
aEvent- The accordingStartedEvent.
-
onStopped
In case a component is to be initialized, then theStoppedEventevent is fired.- Parameters:
aEvent- The accordingStoppedEvent.
-
onDestroyed
In case a component is to be initialized, then theDestroyedEventevent is fired.- Parameters:
aEvent- The accordingDestroyedEvent.
-