Class ObservableLifeCycleRequestAutomatonImpl
- java.lang.Object
-
- org.refcodes.component.LifeCycleAutomatonImpl
-
- org.refcodes.component.ext.observer.ObservableLifeCycleRequestAutomatonImpl
-
- All Implemented Interfaces:
org.refcodes.component.Destroyable,org.refcodes.component.Destroyable.DestroyAutomaton,ObservableLifeCycleRequestAutomaton,org.refcodes.component.Initializable,org.refcodes.component.Initializable.InitializeAutomaton,org.refcodes.component.InitializedAccessor,org.refcodes.component.LifeCycleComponent,org.refcodes.component.LifeCycleComponent.LifeCycleAutomaton,org.refcodes.component.LifeCycleStatusAccessor,org.refcodes.component.Pausable,org.refcodes.component.Pausable.PauseAutomaton,org.refcodes.component.Resumable,org.refcodes.component.Resumable.ResumeAutomaton,org.refcodes.component.RunningAccessor,org.refcodes.component.Startable,org.refcodes.component.Startable.StartAutomaton,org.refcodes.component.Stoppable,org.refcodes.component.Stoppable.StopAutomaton,org.refcodes.mixin.Loggable,org.refcodes.observer.Observable<LifeCycleRequestObserver>
public class ObservableLifeCycleRequestAutomatonImpl extends org.refcodes.component.LifeCycleAutomatonImpl implements ObservableLifeCycleRequestAutomaton, org.refcodes.mixin.Loggable
Abstract implementation of theObservableLifeCycleStatusAutomatoninterface with the according hook methods for you to create your domain drivenObservableLifeCycleStatusAutomaton.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from class org.refcodes.component.LifeCycleAutomatonImpl
org.refcodes.component.LifeCycleAutomatonImpl.ManualLifeCycleAutomatonImpl
-
Nested classes/interfaces inherited from interface org.refcodes.component.Destroyable
org.refcodes.component.Destroyable.DestroyAutomaton
-
Nested classes/interfaces inherited from interface org.refcodes.component.Initializable
org.refcodes.component.Initializable.InitializeAutomaton, org.refcodes.component.Initializable.InitializeBuilder<B extends org.refcodes.component.Initializable.InitializeBuilder<B>>, org.refcodes.component.Initializable.UncheckedInitializable
-
Nested classes/interfaces inherited from interface org.refcodes.component.InitializedAccessor
org.refcodes.component.InitializedAccessor.InitializedMutator, org.refcodes.component.InitializedAccessor.InitializedProperty
-
Nested classes/interfaces inherited from interface org.refcodes.component.LifeCycleComponent
org.refcodes.component.LifeCycleComponent.LifeCycleAutomaton, org.refcodes.component.LifeCycleComponent.UncheckedLifeCycleComponent
-
Nested classes/interfaces inherited from interface org.refcodes.component.LifeCycleStatusAccessor
org.refcodes.component.LifeCycleStatusAccessor.LifeCycleStatusBuilder<B extends org.refcodes.component.LifeCycleStatusAccessor.LifeCycleStatusBuilder<B>>, org.refcodes.component.LifeCycleStatusAccessor.LifeCycleStatusMutator, org.refcodes.component.LifeCycleStatusAccessor.LifeCycleStatusProperty
-
Nested classes/interfaces inherited from interface org.refcodes.component.Pausable
org.refcodes.component.Pausable.PauseAutomaton, org.refcodes.component.Pausable.PauseBuilder<B extends org.refcodes.component.Pausable.PauseBuilder<B>>, org.refcodes.component.Pausable.UncheckedPausable
-
Nested classes/interfaces inherited from interface org.refcodes.component.Resumable
org.refcodes.component.Resumable.ResumeAutomaton, org.refcodes.component.Resumable.ResumeBuilder<B extends org.refcodes.component.Resumable.ResumeBuilder<B>>, org.refcodes.component.Resumable.UncheckedResumable
-
Nested classes/interfaces inherited from interface org.refcodes.component.RunningAccessor
org.refcodes.component.RunningAccessor.RunningMutator, org.refcodes.component.RunningAccessor.RunningProperty
-
-
Constructor Summary
Constructors Constructor Description ObservableLifeCycleRequestAutomatonImpl()Instantiates a new observable life cycle request automaton impl.ObservableLifeCycleRequestAutomatonImpl(Object aSource)ObservableLifeCycleRequestAutomatonImpl(Object aSource, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)ObservableLifeCycleRequestAutomatonImpl(ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent)ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, Object aSource)ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, Object aSource, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, org.refcodes.mixin.EventMetaData aEventMetaData)ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, org.refcodes.mixin.EventMetaData aEventMetaData, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)ObservableLifeCycleRequestAutomatonImpl(org.refcodes.mixin.EventMetaData aEventMetaData)ObservableLifeCycleRequestAutomatonImpl(org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)ObservableLifeCycleRequestAutomatonImpl(org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)ObservableLifeCycleRequestAutomatonImpl(org.refcodes.mixin.EventMetaData aEventMetaData, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description voiddestroy()booleanhasObserverSubscription(LifeCycleRequestObserver aObserver)voidinitialize()voidpause()voidresume()voidstart()voidstop()booleansubscribeObserver(LifeCycleRequestObserver aObserver)booleanunsubscribeObserver(LifeCycleRequestObserver aObserver)-
Methods inherited from class org.refcodes.component.LifeCycleAutomatonImpl
getLifeCycleComponent, getLifeCycleStatus, isDestroyable, isDestroyed, isInitalizable, isInitialized, isPausable, isPaused, isResumable, isRunning, isStartable, isStoppable, isStopped, setLifeCycleStatus
-
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
-
-
Constructor Detail
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl()
Instantiates a new observable life cycle request automaton impl.
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(Object aSource)
- Parameters:
aSource- The source instance to be used when firing events in case the source is to be different from this class' instance.
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(org.refcodes.mixin.EventMetaData aEventMetaData)
- Parameters:
aEventMetaData- TheEventMetaDatato be used when firing events in case theEventMetaDatais to be different from the auto-generatedEventMetaData.
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)- Parameters:
aSource- The source instance to be used when firing events in case the source is to be different from this class' instance.aEventMetaData- TheEventMetaDatato be used when firing events in case theEventMetaDatais to be different from the auto-generatedEventMetaData.
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent)
- Parameters:
aLifeCycleComponent- TheLifeCycleComponentto which the life-cycle method calls are to be delegated to.
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, Object aSource)- Parameters:
aLifeCycleComponent- TheLifeCycleComponentto which the life-cycle method calls are to be delegated to.aSource- The source instance to be used when firing events in case the source is to be different from this class' instance.
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, org.refcodes.mixin.EventMetaData aEventMetaData)- Parameters:
aLifeCycleComponent- TheLifeCycleComponentto which the life-cycle method calls are to be delegated to.aEventMetaData- TheEventMetaDatato be used when firing events in case theEventMetaDatais to be different from the auto-generatedEventMetaData.
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource)- Parameters:
aLifeCycleComponent- TheLifeCycleComponentto which the life-cycle method calls are to be delegated to.aEventMetaData- TheEventMetaDatato be used when firing events in case theEventMetaDatais to be different from the auto-generatedEventMetaData.aSource- The source instance to be used when firing events in case the source is to be different from this class' instance.
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)
- Parameters:
aExecutorService- The executor service to be used when firingGenericActionEventinstances in multiple threads (if null then a default one is used).aExecutionStrategy- TheExecutionStrategyto be used when firingGenericActionEventinstance (if null then the defaultExecutionStrategy.SEQUENTIALis used).
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(Object aSource, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)
- Parameters:
aSource- The source instance to be used when firing events in case the source is to be different from this class' instance.aExecutorService- The executor service to be used when firingGenericActionEventinstances in multiple threads (if null then a default one is used).aExecutionStrategy- TheExecutionStrategyto be used when firingGenericActionEventinstance (if null then the defaultExecutionStrategy.SEQUENTIALis used).
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(org.refcodes.mixin.EventMetaData aEventMetaData, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)- Parameters:
aEventMetaData- TheEventMetaDatato be used when firing events in case theEventMetaDatais to be different from the auto-generatedEventMetaData.aExecutorService- The executor service to be used when firingGenericActionEventinstances in multiple threads (if null then a default one is used).aExecutionStrategy- TheExecutionStrategyto be used when firingGenericActionEventinstance (if null then the defaultExecutionStrategy.SEQUENTIALis used).
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)- Parameters:
aEventMetaData- TheEventMetaDatato be used when firing events in case theEventMetaDatais to be different from the auto-generatedEventMetaData.aSource- The source instance to be used when firing events in case the source is to be different from this class' instance.aExecutorService- The executor service to be used when firingGenericActionEventinstances in multiple threads (if null then a default one is used).aExecutionStrategy- TheExecutionStrategyto be used when firingGenericActionEventinstance (if null then the defaultExecutionStrategy.SEQUENTIALis used).
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)- Parameters:
aLifeCycleComponent- TheLifeCycleComponentto which the life-cycle method calls are to be delegated to.aExecutorService- The executor service to be used when firingGenericActionEventinstances in multiple threads (if null then a default one is used).aExecutionStrategy- TheExecutionStrategyto be used when firingGenericActionEventinstance (if null then the defaultExecutionStrategy.SEQUENTIALis used).
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, Object aSource, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)- Parameters:
aLifeCycleComponent- TheLifeCycleComponentto which the life-cycle method calls are to be delegated to.aSource- The source instance to be used when firing events in case the source is to be different from this class' instance.aExecutorService- The executor service to be used when firingGenericActionEventinstances in multiple threads (if null then a default one is used).aExecutionStrategy- TheExecutionStrategyto be used when firingGenericActionEventinstance (if null then the defaultExecutionStrategy.SEQUENTIALis used).
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, org.refcodes.mixin.EventMetaData aEventMetaData, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)- Parameters:
aLifeCycleComponent- TheLifeCycleComponentto which the life-cycle method calls are to be delegated to.aEventMetaData- TheEventMetaDatato be used when firing events in case theEventMetaDatais to be different from the auto-generatedEventMetaData.aExecutorService- The executor service to be used when firingGenericActionEventinstances in multiple threads (if null then a default one is used).aExecutionStrategy- TheExecutionStrategyto be used when firingGenericActionEventinstance (if null then the defaultExecutionStrategy.SEQUENTIALis used).
-
ObservableLifeCycleRequestAutomatonImpl
public ObservableLifeCycleRequestAutomatonImpl(org.refcodes.component.LifeCycleComponent aLifeCycleComponent, org.refcodes.mixin.EventMetaData aEventMetaData, Object aSource, ExecutorService aExecutorService, org.refcodes.controlflow.ExecutionStrategy aExecutionStrategy)- Parameters:
aLifeCycleComponent- TheLifeCycleComponentto which the life-cycle method calls are to be delegated to.aEventMetaData- TheEventMetaDatato be used when firing events in case theEventMetaDatais to be different from the auto-generatedEventMetaData.aSource- The source instance to be used when firing events in case the source is to be different from this class' instance.aExecutorService- The executor service to be used when firingGenericActionEventinstances in multiple threads (if null then a default one is used).aExecutionStrategy- TheExecutionStrategyto be used when firingGenericActionEventinstance (if null then the defaultExecutionStrategy.SEQUENTIALis used).
-
-
Method Detail
-
hasObserverSubscription
public boolean hasObserverSubscription(LifeCycleRequestObserver aObserver)
- Specified by:
hasObserverSubscriptionin interfaceorg.refcodes.observer.Observable<LifeCycleRequestObserver>
-
subscribeObserver
public boolean subscribeObserver(LifeCycleRequestObserver aObserver)
- Specified by:
subscribeObserverin interfaceorg.refcodes.observer.Observable<LifeCycleRequestObserver>
-
unsubscribeObserver
public boolean unsubscribeObserver(LifeCycleRequestObserver aObserver)
- Specified by:
unsubscribeObserverin interfaceorg.refcodes.observer.Observable<LifeCycleRequestObserver>
-
initialize
public void initialize() throws org.refcodes.component.InitializeException- Specified by:
initializein interfaceorg.refcodes.component.Initializable- Overrides:
initializein classorg.refcodes.component.LifeCycleAutomatonImpl- Throws:
org.refcodes.component.InitializeException
-
start
public void start() throws org.refcodes.component.StartException- Specified by:
startin interfaceorg.refcodes.component.Startable- Overrides:
startin classorg.refcodes.component.LifeCycleAutomatonImpl- Throws:
org.refcodes.component.StartException
-
pause
public void pause() throws org.refcodes.component.PauseException- Specified by:
pausein interfaceorg.refcodes.component.Pausable- Overrides:
pausein classorg.refcodes.component.LifeCycleAutomatonImpl- Throws:
org.refcodes.component.PauseException
-
resume
public void resume() throws org.refcodes.component.ResumeException- Specified by:
resumein interfaceorg.refcodes.component.Resumable- Overrides:
resumein classorg.refcodes.component.LifeCycleAutomatonImpl- Throws:
org.refcodes.component.ResumeException
-
stop
public void stop() throws org.refcodes.component.StopException- Specified by:
stopin interfaceorg.refcodes.component.Stoppable- Overrides:
stopin classorg.refcodes.component.LifeCycleAutomatonImpl- Throws:
org.refcodes.component.StopException
-
destroy
public void destroy()
- Specified by:
destroyin interfaceorg.refcodes.component.Destroyable- Overrides:
destroyin classorg.refcodes.component.LifeCycleAutomatonImpl
-
-