Interface ObservableLifecycleStatusAutomaton
- All Superinterfaces:
org.refcodes.component.Destroyable,org.refcodes.component.Destroyable.DestroyAutomaton,org.refcodes.component.Initializable,org.refcodes.component.Initializable.InitializeAutomaton,org.refcodes.component.InitializedAccessor,org.refcodes.component.LifecycleComponent,org.refcodes.component.LifecycleComponent.LifecycleAutomaton,org.refcodes.component.LifecycleStatusAccessor,org.refcodes.observer.Observable<LifecycleStatusObserver>,org.refcodes.component.Pausable,org.refcodes.component.Pausable.PauseAutomaton,org.refcodes.component.Resumable,org.refcodes.component.Resumable.ResumeAutomaton,org.refcodes.component.RunningAccessor,org.refcodes.component.Startable,org.refcodes.component.Startable.StartAutomaton,org.refcodes.component.Stoppable,org.refcodes.component.Stoppable.StopAutomaton
- All Known Implementing Classes:
ObservableLifecycleStatusAutomatonImpl
public interface ObservableLifecycleStatusAutomaton
extends org.refcodes.component.LifecycleComponent.LifecycleAutomaton, org.refcodes.observer.Observable<LifecycleStatusObserver>
A system implementing this interface supports a component life-cycle. I.e.
such a component may be instructed from the outside to run through several
stages from getting started till being destroyed. The valid state changes are
mainly as follows:
"start" - "pause" - "resume" - "stop" - "destroy"
For example:
"start" - "pause" - "resume" - "pause" - "resume" - "stop" - "start" - "pause" - "resume" - "stop" - "destroy"
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.component.Destroyable
org.refcodes.component.Destroyable.DestroyAutomatonNested classes/interfaces inherited from interface org.refcodes.component.Initializable
org.refcodes.component.Initializable.InitializeAutomaton, org.refcodes.component.Initializable.InitializeBuilder<B extends org.refcodes.component.Initializable.InitializeBuilder<B>>, org.refcodes.component.Initializable.UncheckedInitializableNested classes/interfaces inherited from interface org.refcodes.component.InitializedAccessor
org.refcodes.component.InitializedAccessor.InitializedMutator, org.refcodes.component.InitializedAccessor.InitializedPropertyNested classes/interfaces inherited from interface org.refcodes.component.LifecycleComponent
org.refcodes.component.LifecycleComponent.LifecycleAutomaton, org.refcodes.component.LifecycleComponent.UncheckedLifecycleComponentNested classes/interfaces inherited from interface org.refcodes.component.LifecycleStatusAccessor
org.refcodes.component.LifecycleStatusAccessor.LifecycleStatusBuilder<B extends org.refcodes.component.LifecycleStatusAccessor.LifecycleStatusBuilder<B>>, org.refcodes.component.LifecycleStatusAccessor.LifecycleStatusMutator, org.refcodes.component.LifecycleStatusAccessor.LifecycleStatusPropertyNested classes/interfaces inherited from interface org.refcodes.component.Pausable
org.refcodes.component.Pausable.PauseAutomaton, org.refcodes.component.Pausable.PauseBuilder<B extends org.refcodes.component.Pausable.PauseBuilder<B>>, org.refcodes.component.Pausable.UncheckedPausableNested classes/interfaces inherited from interface org.refcodes.component.Resumable
org.refcodes.component.Resumable.ResumeAutomaton, org.refcodes.component.Resumable.ResumeBuilder<B extends org.refcodes.component.Resumable.ResumeBuilder<B>>, org.refcodes.component.Resumable.UncheckedResumableNested classes/interfaces inherited from interface org.refcodes.component.RunningAccessor
org.refcodes.component.RunningAccessor.RunningMutator, org.refcodes.component.RunningAccessor.RunningPropertyNested classes/interfaces inherited from interface org.refcodes.component.Startable
org.refcodes.component.Startable.StartAutomaton, org.refcodes.component.Startable.StartBuilder<B extends org.refcodes.component.Startable.StartBuilder<B>>, org.refcodes.component.Startable.UncheckedStartableNested classes/interfaces inherited from interface org.refcodes.component.Stoppable
org.refcodes.component.Stoppable.StopAutomaton, org.refcodes.component.Stoppable.StopBuilder<B extends org.refcodes.component.Stoppable.StopBuilder<B>>, org.refcodes.component.Stoppable.UncheckedStoppable -
Method Summary
Methods inherited from interface org.refcodes.component.Destroyable
destroyMethods inherited from interface org.refcodes.component.Destroyable.DestroyAutomaton
isDestroyable, isDestroyedMethods inherited from interface org.refcodes.component.Initializable
initialize, initializeUncheckedMethods inherited from interface org.refcodes.component.Initializable.InitializeAutomaton
isInitalizableMethods inherited from interface org.refcodes.component.InitializedAccessor
isInitializedMethods inherited from interface org.refcodes.component.LifecycleStatusAccessor
getLifecycleStatusMethods inherited from interface org.refcodes.observer.Observable
hasObserverSubscription, subscribeObserver, unsubscribeObserverMethods inherited from interface org.refcodes.component.Pausable
pause, pauseUncheckedMethods inherited from interface org.refcodes.component.Pausable.PauseAutomaton
isPausable, isPausedMethods inherited from interface org.refcodes.component.Resumable
resume, resumeUncheckedMethods inherited from interface org.refcodes.component.Resumable.ResumeAutomaton
isResumableMethods inherited from interface org.refcodes.component.RunningAccessor
isRunningMethods inherited from interface org.refcodes.component.Startable
start, startUncheckedMethods inherited from interface org.refcodes.component.Startable.StartAutomaton
isStartableMethods inherited from interface org.refcodes.component.Stoppable
stop, stopUncheckedMethods inherited from interface org.refcodes.component.Stoppable.StopAutomaton
isStoppable, isStopped