Package org.refcodes.component.ext.observer
package org.refcodes.component.ext.observer
-
ClassDescriptionAbstractConnectionRequestEvent<A,
META extends org.refcodes.mixin.EventMetaData, SRC> Abstract implementation of the baseGenericConnectionRequestEvent.AbstractConnectionStatusEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> Abstract implementation of the baseGenericConnectionStatusEvent.AbstractLifecycleRequestEvent<META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericLifecycleRequestEvent.AbstractLifecycleStatusEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> Abstract implementation of the baseGenericLifecycleStatusEvent.AbstractNetworkRequestEvent<CON,A, META extends org.refcodes.mixin.EventMetaData, SRC> Abstract implementation of the baseGenericNetworkRequestEvent.AbstractNetworkStatusEvent<CON,A, META extends org.refcodes.mixin.EventMetaData, SRC> Abstract implementation of the baseGenericNetworkStatusEvent.Implementation of theConnectionStatusEventforConnectionStatus.CLOSED.Implementation of theConnectionRequestEventforConnectionRequest.CLOSE.An observer for listening toConnectionStatusEventinstances.An observer for listening toConnectionRequestEventinstances.Provides an accessor for aConnectionRequestproperty.Provides a mutator for aConnectionRequestproperty.Provides aConnectionRequestproperty.TheConnectionRequestEventrepresents aConnectionRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.TheConnectionStatusEventindicates theConnectionStatusfor a component.Implementation of theLifecycleStatusEventforLifecycleStatus.DESTROYED.Implementation of theLifecycleRequestEventforLifecycleRequest.DESTROY.GenericClosedEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericClosedEventsignals aConnectionStatus.CLOSEDevent.GenericCloseEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericCloseEventsignals aConnectionRequest.CLOSEevent.GenericConnectionRequestEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericConnectionRequestEventrepresents aConnectionRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericConnectionStatusEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericConnectionStatusEventindicates theConnectionStatusfor a connection.GenericDestroyedEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericDestroyedEventsignals aLifecycleStatus.DESTROYEDevent.GenericDestroyEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericDestroyEventsignals aLifecycleRequest.DESTROYevent.GenericInitializedEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericInitializedEventsignals aLifecycleStatus.INITIALIZEDevent.GenericInitializeEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericInitializeEventsignals aLifecycleRequest.INITIALIZEevent.GenericLifecycleRequestEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericLifecycleRequestEventrepresents aLifecycleRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericLifecycleRequestObserver<A,INIT extends GenericInitializeEvent<A, META, SRC>, START extends GenericStartEvent<A, META, SRC>, RESUME extends GenericResumeEvent<A, META, SRC>, PAUSE extends GenericPauseEvent<A, META, SRC>, STOP extends GenericStopEvent<A, META, SRC>, DESTROY extends GenericDestroyEvent<A, META, SRC>, META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericLifecycleRequestObserveris signaled uponGenericLifecycleRequestEventevents.GenericLifecycleStatusEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericLifecycleStatusEventindicates theLifecycleStatusfor a component.GenericLifecycleStatusObserver<A,INITED extends GenericInitializedEvent<A, META, SRC>, STARTED extends GenericStartedEvent<A, META, SRC>, RESUMED extends GenericResumedEvent<A, META, SRC>, PAUSED extends GenericPausedEvent<A, META, SRC>, STOPPED extends GenericStoppedEvent<A, META, SRC>, DESTROYED extends GenericDestroyedEvent<A, META, SRC>, META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericLifecycleStatusObserveris signaled uponGenericLifecycleStatusEventevents.GenericNetworkRequestEvent<CON,A, META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericNetworkRequestEventrepresents aConnectionRequestfor a connection and might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericNetworkStatusEvent<CON,A, META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericNetworkStatusEventindicates theConnectionStatusfor a component's connection.GenericOpenedEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericOpenedEventsignals aConnectionStatus.OPENEDevent.GenericOpenEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericOpenEventsignals aConnectionRequest.OPENevent.GenericPausedEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericPausedEventsignals aLifecycleStatus.PAUSEDevent.GenericPauseEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericPauseEventsignals aLifecycleRequest.PAUSEevent.GenericResumedEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericResumedEventsignals aLifecycleStatus.STARTEDevent.GenericResumeEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericResumeEventsignals aLifecycleRequest.RESUMEevent.GenericStartedEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericStartedEventsignals aLifecycleStatus.STARTEDevent.GenericStartEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericStartEventsignals aLifecycleRequest.STARTevent.GenericStopEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericStopEventsignals aLifecycleRequest.STOPevent.GenericStoppedEvent<A,META extends org.refcodes.mixin.EventMetaData, SRC> TheGenericStoppedEventsignals aLifecycleStatus.STOPPEDevent.Implementation of theLifecycleStatusEventforLifecycleStatus.INITIALIZED.Implementation of theLifecycleRequestEventforLifecycleRequest.INITIALIZE.TheLifecycleRequestEventrepresents aLifecycleRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.An observer for listening toLifecycleRequestEventinstances.TTheLifecycleStatusEventindicates theLifecycleStatusfor a component.An observer for listening toLifecycleStatusEventinstances.NetworkRequestEvent<CON>TheNetworkRequestEventrepresents aConnectionRequestfor a connection and might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.NetworkStatusEvent<CON>TheNetworkStatusEventindicates theConnectionStatusfor a component's connection.Provides an accessor for anObservableLifecycleStatusAutomatonproperty.Provides a mutator for anObservableLifecycleStatusAutomatonproperty.Provides anObservableLifecycleStatusAutomatonproperty.TheObservableLifecycleRequestAutomatonextends theObservableLifecycleStatusAutomatonwith requestGenericActionEventfunctionality which can be vetoed.Abstract implementation of theObservableLifecycleStatusAutomatoninterface with the according hook methods for you to create your domain drivenObservableLifecycleStatusAutomaton.A system implementing this interface supports a component life-cycle.Abstract implementation of theObservableLifecycleStatusAutomatoninterface with the according hook methods for you to create your domain drivenObservableLifecycleStatusAutomaton.Implementation of theConnectionStatusEventforConnectionStatus.OPENED.Implementation of theConnectionRequestEventforConnectionRequest.OPEN.Implementation of theLifecycleStatusEventforLifecycleStatus.PAUSED.Implementation of theLifecycleRequestEventforLifecycleRequest.PAUSE.Implementation of theLifecycleStatusEventforLifecycleStatus.STARTED.Implementation of theLifecycleRequestEventforLifecycleRequest.RESUME.Implementation of theLifecycleStatusEventforLifecycleStatus.STARTED.Implementation of theLifecycleRequestEventforLifecycleRequest.START.Implementation of theLifecycleRequestEventforLifecycleRequest.STOP.Implementation of theLifecycleStatusEventforLifecycleStatus.STOPPED.