Uses of Package
org.refcodes.component.ext.observer
-
Classes in org.refcodes.component.ext.observer used by org.refcodes.component.ext.observerClassDescriptionAbstract implementation of the base
GenericConnectionRequestEvent.Abstract implementation of the baseGenericConnectionStatusEvent.Implementation of theConnectionStatusEventforConnectionStatus.CLOSED.Implementation of theConnectionRequestEventforConnectionRequest.CLOSE.An observer for listening toConnectionStatusEventinstances.Provides an accessor for aConnectionRequestproperty.Provides a mutator for aConnectionRequestproperty.TheConnectionRequestEventrepresents aConnectionRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.TheConnectionStatusEventindicates theConnectionStatusfor a component.TheGenericClosedEventsignals aConnectionStatus.CLOSEDevent.TheGenericCloseEventsignals aConnectionRequest.CLOSEevent.TheGenericConnectionRequestEventrepresents aConnectionRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.TheGenericConnectionStatusEventindicates theConnectionStatusfor a connection.TheGenericDestroyedEventsignals aLifecycleStatus.DESTROYEDevent.TheGenericDestroyEventsignals aLifecycleRequest.DESTROYevent.TheGenericInitializedEventsignals aLifecycleStatus.INITIALIZEDevent.TheGenericInitializeEventsignals aLifecycleRequest.INITIALIZEevent.TheGenericLifecycleRequestEventrepresents aLifecycleRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.TheGenericLifecycleRequestObserveris signaled uponGenericLifecycleRequestEventevents.TheGenericLifecycleStatusEventindicates theLifecycleStatusfor a component.TheGenericLifecycleStatusObserveris signaled uponGenericLifecycleStatusEventevents.TheGenericNetworkRequestEventrepresents aConnectionRequestfor a connection and might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.TheGenericNetworkStatusEventindicates theConnectionStatusfor a component's connection.TheGenericOpenedEventsignals aConnectionStatus.OPENEDevent.TheGenericOpenEventsignals aConnectionRequest.OPENevent.TheGenericPausedEventsignals aLifecycleStatus.PAUSEDevent.TheGenericPauseEventsignals aLifecycleRequest.PAUSEevent.TheGenericResumedEventsignals aLifecycleStatus.STARTEDevent.TheGenericResumeEventsignals aLifecycleRequest.RESUMEevent.TheGenericStartedEventsignals aLifecycleStatus.STARTEDevent.TheGenericStartEventsignals aLifecycleRequest.STARTevent.TheGenericStopEventsignals aLifecycleRequest.STOPevent.TheGenericStoppedEventsignals aLifecycleStatus.STOPPEDevent.TheLifecycleRequestEventrepresents aLifecycleRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.An observer for listening toLifecycleRequestEventinstances.TTheLifecycleStatusEventindicates theLifecycleStatusfor a component.An observer for listening toLifecycleStatusEventinstances.Provides an accessor for anObservableLifecycleStatusAutomatonproperty.Provides a mutator for anObservableLifecycleStatusAutomatonproperty.TheObservableLifecycleRequestAutomatonextends theObservableLifecycleStatusAutomatonwith requestGenericActionEventfunctionality which can be vetoed.A system implementing this interface supports a component life-cycle.Implementation of theConnectionStatusEventforConnectionStatus.OPENED.Implementation of theConnectionRequestEventforConnectionRequest.OPEN.