Interface ConnectionObserver.ConnectionRequestObserver
- All Superinterfaces:
ConnectionObserver,org.refcodes.observer.Observer<org.refcodes.observer.MetaDataEvent>
- Enclosing interface:
- ConnectionObserver
An observer for listening to
ConnectionRequestEvent instances.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.component.ext.observer.ConnectionObserver
ConnectionObserver.ConnectionRequestObserver -
Method Summary
Modifier and TypeMethodDescriptionvoidonCloseEvent(CloseEvent aEvent) In case a device is to be closed, then theCloseEventevent is fired.voidonOpenEvent(OpenEvent aEvent) In case a device is to be opened, then theOpenEventevent is fired.Methods inherited from interface org.refcodes.component.ext.observer.ConnectionObserver
onClosedEvent, onOpendEventMethods inherited from interface org.refcodes.observer.Observer
onEvent
-
Method Details
-
onOpenEvent
In case a device is to be opened, then theOpenEventevent is fired.- Parameters:
aEvent- The accordingOpenEvent.- Throws:
org.refcodes.exception.VetoException- the veto exception
-
onCloseEvent
In case a device is to be closed, then theCloseEventevent is fired.- Parameters:
aEvent- The accordingCloseEvent.- Throws:
org.refcodes.exception.VetoException- the veto exception
-