Interface ConnectionObserver.ConnectionRequestObserver
-
- All Superinterfaces:
ConnectionObserver,org.refcodes.observer.Observer<org.refcodes.observer.MetaDataEvent>
- Enclosing interface:
- ConnectionObserver
public static interface ConnectionObserver.ConnectionRequestObserver extends ConnectionObserver
An observer for listening toConnectionRequestEventinstances.
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.component.ext.observer.ConnectionObserver
ConnectionObserver.ConnectionRequestObserver
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidonCloseEvent(CloseEvent aEvent)In case a device is to be closed, then theCloseEventevent is fired.voidonOpenEvent(OpenEvent aEvent)In case a device is to be opened, then theOpenEventevent is fired.-
Methods inherited from interface org.refcodes.component.ext.observer.ConnectionObserver
onClosedEvent, onOpendEvent
-
-
-
-
Method Detail
-
onOpenEvent
void onOpenEvent(OpenEvent aEvent) throws org.refcodes.exception.VetoException
In case a device is to be opened, then theOpenEventevent is fired.- Parameters:
aEvent- The accordingOpenEvent.- Throws:
org.refcodes.exception.VetoException- the veto exception
-
onCloseEvent
void onCloseEvent(CloseEvent aEvent) throws org.refcodes.exception.VetoException
In case a device is to be closed, then theCloseEventevent is fired.- Parameters:
aEvent- The accordingCloseEvent.- Throws:
org.refcodes.exception.VetoException- the veto exception
-
-