Interface GenericLifecycleStatusObserver<A,INITED extends GenericInitializedEvent<A,META,SRC>,STARTED extends GenericStartedEvent<A,META,SRC>,RESUMED extends GenericResumedEvent<A,META,SRC>,PAUSED extends GenericPausedEvent<A,META,SRC>,STOPPED extends GenericStoppedEvent<A,META,SRC>,DESTROYED extends GenericDestroyedEvent<A,META,SRC>,META extends org.refcodes.mixin.EventMetaData,SRC>
-
- All Known Subinterfaces:
LifecycleStatusObserver
public interface GenericLifecycleStatusObserver<A,INITED extends GenericInitializedEvent<A,META,SRC>,STARTED extends GenericStartedEvent<A,META,SRC>,RESUMED extends GenericResumedEvent<A,META,SRC>,PAUSED extends GenericPausedEvent<A,META,SRC>,STOPPED extends GenericStoppedEvent<A,META,SRC>,DESTROYED extends GenericDestroyedEvent<A,META,SRC>,META extends org.refcodes.mixin.EventMetaData,SRC>TheGenericLifecycleStatusObserveris signaled uponGenericLifecycleStatusEventevents.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidonDestroyed(DESTROYED aEvent)In case a component is to be initialized, then theGenericDestroyedEventevent is fired.voidonInitialized(INITED aEvent)In case a component is to be initialized, then theGenericInitializedEventevent is fired.voidonPaused(PAUSED aEvent)In case a component is to be initialized, then theGenericStartedEventevent is fired.voidonResumed(RESUMED aEvent)In case a component is to be initialized, then theGenericResumedEventevent is fired.voidonStarted(STARTED aEvent)In case a component is to be initialized, then theGenericStartedEventevent is fired.voidonStopped(STOPPED aEvent)In case a component is to be initialized, then theGenericStoppedEventevent is fired.
-
-
-
Method Detail
-
onInitialized
void onInitialized(INITED aEvent)
In case a component is to be initialized, then theGenericInitializedEventevent is fired.- Parameters:
aEvent- The accordingGenericInitializedEvent.
-
onStarted
void onStarted(STARTED aEvent)
In case a component is to be initialized, then theGenericStartedEventevent is fired.- Parameters:
aEvent- The accordingGenericStartedEvent.
-
onResumed
void onResumed(RESUMED aEvent)
In case a component is to be initialized, then theGenericResumedEventevent is fired.- Parameters:
aEvent- The accordingGenericResumedEvent.
-
onPaused
void onPaused(PAUSED aEvent)
In case a component is to be initialized, then theGenericStartedEventevent is fired.- Parameters:
aEvent- The accordingGenericStartedEvent.
-
onStopped
void onStopped(STOPPED aEvent)
In case a component is to be initialized, then theGenericStoppedEventevent is fired.- Parameters:
aEvent- The accordingGenericStoppedEvent.
-
onDestroyed
void onDestroyed(DESTROYED aEvent)
In case a component is to be initialized, then theGenericDestroyedEventevent is fired.- Parameters:
aEvent- The accordingGenericDestroyedEvent.
-
-