Interface LifecycleRequestObserver<INIT extends InitializeRequestedEvent<SRC>, START extends StartRequestedEvent<SRC>, RESUME extends ResumeRequestedEvent<SRC>, PAUSE extends PauseRequestedEvent<SRC>, STOP extends StopRequestedEvent<SRC>, DESTROY extends DestroyRequestedEvent<SRC>, META extends org.refcodes.observer.EventMetaData, SRC>
- Type Parameters:
INIT- the generic typeSTART- the generic typeRESUME- the generic typePAUSE- the generic typeSTOP- the generic typeDESTROY- the generic typeMETA- the generic typeSRC- The source of the events consumed by theLifecycleRequestObserver.
public interface LifecycleRequestObserver<INIT extends InitializeRequestedEvent<SRC>, START extends StartRequestedEvent<SRC>, RESUME extends ResumeRequestedEvent<SRC>, PAUSE extends PauseRequestedEvent<SRC>, STOP extends StopRequestedEvent<SRC>, DESTROY extends DestroyRequestedEvent<SRC>, META extends org.refcodes.observer.EventMetaData, SRC>
An observer for listening to
LifecycleRequestEvent instances.-
Method Summary
Modifier and TypeMethodDescriptionvoidIn case a component is to be initialized, then theDestroyEventevent is fired.voidonInitialize(INIT aEvent) In case a component is to be initialized, then theInitializeEventevent is fired.voidIn case a component is to be initialized, then thePauseEventevent is fired.voidIn case a component is to be initialized, then theResumeEventevent is fired.voidIn case a component is to be initialized, then theStartEventevent is fired.voidIn case a component is to be initialized, then theStopEventevent is fired.
-
Method Details
-
onInitialize
In case a component is to be initialized, then theInitializeEventevent is fired.- Parameters:
aEvent- The accordingInitializeEvent.
-
onStart
In case a component is to be initialized, then theStartEventevent is fired.- Parameters:
aEvent- The accordingStartEvent.
-
onResume
In case a component is to be initialized, then theResumeEventevent is fired.- Parameters:
aEvent- The accordingResumeEvent.
-
onPause
In case a component is to be initialized, then thePauseEventevent is fired.- Parameters:
aEvent- The accordingPauseEvent.
-
onStop
-
onDestroy
In case a component is to be initialized, then theDestroyEventevent is fired.- Parameters:
aEvent- The accordingDestroyEvent.
-