Package org.refcodes.component.ext.observer
-
Interface Summary Interface Description ConnectionObserver An observer for listening toConnectionStatusEventinstances.ConnectionObserver.ConnectionRequestObserver An observer for listening toConnectionRequestEventinstances.ConnectionRequestAccessor Provides an accessor for aConnectionRequestproperty.ConnectionRequestAccessor.ConnectionRequestMutator Provides a mutator for aConnectionRequestproperty.ConnectionRequestAccessor.ConnectionRequestProperty Provides aConnectionRequestproperty.ConnectionRequestEvent TheConnectionRequestEventrepresents aConnectionRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.ConnectionStatusEvent TheConnectionStatusEventindicates theConnectionStatusfor a component.GenericClosedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericClosedEventsignals aConnectionStatus.CLOSEDevent.GenericCloseEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericCloseEventsignals aConnectionRequest.CLOSEevent.GenericConnectionRequestEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericConnectionRequestEventrepresents aConnectionRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericConnectionStatusEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericConnectionStatusEventindicates theConnectionStatusfor a connection.GenericDestroyedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericDestroyedEventsignals aLifecycleStatus.DESTROYEDevent.GenericDestroyEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericDestroyEventsignals aLifecycleRequest.DESTROYevent.GenericInitializedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericInitializedEventsignals aLifecycleStatus.INITIALIZEDevent.GenericInitializeEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericInitializeEventsignals aLifecycleRequest.INITIALIZEevent.GenericLifecycleRequestEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericLifecycleRequestEventrepresents aLifecycleRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericLifecycleRequestObserver<A,INIT extends GenericInitializeEvent<A,META,SRC>,START extends GenericStartEvent<A,META,SRC>,RESUME extends GenericResumeEvent<A,META,SRC>,PAUSE extends GenericPauseEvent<A,META,SRC>,STOP extends GenericStopEvent<A,META,SRC>,DESTROY extends GenericDestroyEvent<A,META,SRC>,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericLifecycleRequestObserveris signaled uponGenericLifecycleRequestEventevents.GenericLifecycleStatusEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericLifecycleStatusEventindicates theLifecycleStatusfor a component.GenericLifecycleStatusObserver<A,INITED extends GenericInitializedEvent<A,META,SRC>,STARTED extends GenericStartedEvent<A,META,SRC>,RESUMED extends GenericResumedEvent<A,META,SRC>,PAUSED extends GenericPausedEvent<A,META,SRC>,STOPPED extends GenericStoppedEvent<A,META,SRC>,DESTROYED extends GenericDestroyedEvent<A,META,SRC>,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericLifecycleStatusObserveris signaled uponGenericLifecycleStatusEventevents.GenericNetworkRequestEvent<CON,A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericNetworkRequestEventrepresents aConnectionRequestfor a connection and might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericNetworkStatusEvent<CON,A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericNetworkStatusEventindicates theConnectionStatusfor a component's connection.GenericOpenedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericOpenedEventsignals aConnectionStatus.OPENEDevent.GenericOpenEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericOpenEventsignals aConnectionRequest.OPENevent.GenericPausedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericPausedEventsignals aLifecycleStatus.PAUSEDevent.GenericPauseEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericPauseEventsignals aLifecycleRequest.PAUSEevent.GenericResumedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericResumedEventsignals aLifecycleStatus.STARTEDevent.GenericResumeEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericResumeEventsignals aLifecycleRequest.RESUMEevent.GenericStartedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericStartedEventsignals aLifecycleStatus.STARTEDevent.GenericStartEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericStartEventsignals aLifecycleRequest.STARTevent.GenericStopEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericStopEventsignals aLifecycleRequest.STOPevent.GenericStoppedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericStoppedEventsignals aLifecycleStatus.STOPPEDevent.LifecycleRequestEvent TheLifecycleRequestEventrepresents aLifecycleRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.LifecycleRequestObserver An observer for listening toLifecycleRequestEventinstances.LifecycleStatusEvent TTheLifecycleStatusEventindicates theLifecycleStatusfor a component.LifecycleStatusObserver An observer for listening toLifecycleStatusEventinstances.NetworkRequestEvent<CON> TheNetworkRequestEventrepresents aConnectionRequestfor a connection and might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.NetworkStatusEvent<CON> TheNetworkStatusEventindicates theConnectionStatusfor a component's connection.ObservableLifecycleAutomatonAccessor Provides an accessor for anObservableLifecycleStatusAutomatonproperty.ObservableLifecycleAutomatonAccessor.ObservableLifecycleAutomatonMutator Provides a mutator for anObservableLifecycleStatusAutomatonproperty.ObservableLifecycleAutomatonAccessor.ObservableLifecycleAutomatonProperty Provides anObservableLifecycleStatusAutomatonproperty.ObservableLifecycleRequestAutomaton TheObservableLifecycleRequestAutomatonextends theObservableLifecycleStatusAutomatonwith requestGenericActionEventfunctionality which can be vetoed.ObservableLifecycleStatusAutomaton A system implementing this interface supports a component life-cycle. -
Class Summary Class Description AbstractConnectionRequestEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericConnectionRequestEvent.AbstractConnectionStatusEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericConnectionStatusEvent.AbstractLifecycleRequestEvent<META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericLifecycleRequestEvent.AbstractLifecycleStatusEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericLifecycleStatusEvent.AbstractNetworkRequestEvent<CON,A,META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericNetworkRequestEvent.AbstractNetworkStatusEvent<CON,A,META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericNetworkStatusEvent.ClosedEvent Implementation of theConnectionStatusEventforConnectionStatus.CLOSED.CloseEvent Implementation of theConnectionRequestEventforConnectionRequest.CLOSE.DestroyedEvent Implementation of theLifecycleStatusEventforLifecycleStatus.DESTROYED.DestroyEvent Implementation of theLifecycleRequestEventforLifecycleRequest.DESTROY.InitializedEvent Implementation of theLifecycleStatusEventforLifecycleStatus.INITIALIZED.InitializeEvent Implementation of theLifecycleRequestEventforLifecycleRequest.INITIALIZE.ObservableLifecycleRequestAutomatonImpl Abstract implementation of theObservableLifecycleStatusAutomatoninterface with the according hook methods for you to create your domain drivenObservableLifecycleStatusAutomaton.ObservableLifecycleStatusAutomatonImpl Abstract implementation of theObservableLifecycleStatusAutomatoninterface with the according hook methods for you to create your domain drivenObservableLifecycleStatusAutomaton.OpenedEvent Implementation of theConnectionStatusEventforConnectionStatus.OPENED.OpenEvent Implementation of theConnectionRequestEventforConnectionRequest.OPEN.PausedEvent Implementation of theLifecycleStatusEventforLifecycleStatus.PAUSED.PauseEvent Implementation of theLifecycleRequestEventforLifecycleRequest.PAUSE.ResumedEvent Implementation of theLifecycleStatusEventforLifecycleStatus.STARTED.ResumeEvent Implementation of theLifecycleRequestEventforLifecycleRequest.RESUME.StartedEvent Implementation of theLifecycleStatusEventforLifecycleStatus.STARTED.StartEvent Implementation of theLifecycleRequestEventforLifecycleRequest.START.StopEvent Implementation of theLifecycleRequestEventforLifecycleRequest.STOP.StoppedEvent Implementation of theLifecycleStatusEventforLifecycleStatus.STOPPED.