Package org.refcodes.component.ext.observer
-
Interface Summary Interface Description ConnectionObserver An observer for listening toConnectionStatusEventinstances.ConnectionObserver.ConnectionRequestObserver An observer for listening toConnectionRequestEventinstances.ConnectionRequestAccessor Provides an accessor for aConnectionRequestproperty.ConnectionRequestAccessor.ConnectionRequestMutator Provides a mutator for aConnectionRequestproperty.ConnectionRequestAccessor.ConnectionRequestProperty Provides aConnectionRequestproperty.ConnectionRequestEvent TheConnectionRequestEventrepresents aConnectionRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.ConnectionStatusEvent TheConnectionStatusEventindicates theConnectionStatusfor a component.GenericClosedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericClosedEventsignals aConnectionStatus.CLOSEDevent.GenericCloseEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericCloseEventsignals aConnectionRequest.CLOSEevent.GenericConnectionRequestEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericConnectionRequestEventrepresents aConnectionRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericConnectionStatusEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericConnectionStatusEventindicates theConnectionStatusfor a connection.GenericDestroyedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericDestroyedEventsignals aLifeCycleStatus.DESTROYEDevent.GenericDestroyEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericDestroyEventsignals aLifeCycleRequest.DESTROYevent.GenericInitializedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericInitializedEventsignals aLifeCycleStatus.INITIALIZEDevent.GenericInitializeEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericInitializeEventsignals aLifeCycleRequest.INITIALIZEevent.GenericLifeCycleRequestEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericLifeCycleRequestEventrepresents aLifeCycleRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericLifeCycleRequestObserver<A,INIT extends GenericInitializeEvent<A,META,SRC>,START extends GenericStartEvent<A,META,SRC>,RESUME extends GenericResumeEvent<A,META,SRC>,PAUSE extends GenericPauseEvent<A,META,SRC>,STOP extends GenericStopEvent<A,META,SRC>,DESTROY extends GenericDestroyEvent<A,META,SRC>,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericLifeCycleRequestObserveris signaled uponGenericLifeCycleRequestEventevents.GenericLifeCycleStatusEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericLifeCycleStatusEventindicates theLifeCycleStatusfor a component.GenericLifeCycleStatusObserver<A,INITED extends GenericInitializedEvent<A,META,SRC>,STARTED extends GenericStartedEvent<A,META,SRC>,RESUMED extends GenericResumedEvent<A,META,SRC>,PAUSED extends GenericPausedEvent<A,META,SRC>,STOPPED extends GenericStoppedEvent<A,META,SRC>,DESTROYED extends GenericDestroyedEvent<A,META,SRC>,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericLifeCycleStatusObserveris signaled uponGenericLifeCycleStatusEventevents.GenericNetworkRequestEvent<CON,A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericNetworkRequestEventrepresents aConnectionRequestfor a connection and might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericNetworkStatusEvent<CON,A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericNetworkStatusEventindicates theConnectionStatusfor a component's connection.GenericOpenedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericOpenedEventsignals aConnectionStatus.OPENEDevent.GenericOpenEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericOpenEventsignals aConnectionRequest.OPENevent.GenericPausedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericPausedEventsignals aLifeCycleStatus.PAUSEDevent.GenericPauseEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericPauseEventsignals aLifeCycleRequest.PAUSEevent.GenericResumedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericResumedEventsignals aLifeCycleStatus.STARTEDevent.GenericResumeEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericResumeEventsignals aLifeCycleRequest.RESUMEevent.GenericStartedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericStartedEventsignals aLifeCycleStatus.STARTEDevent.GenericStartEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericStartEventsignals aLifeCycleRequest.STARTevent.GenericStopEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericStopEventsignals aLifeCycleRequest.STOPevent.GenericStoppedEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> TheGenericStoppedEventsignals aLifeCycleStatus.STOPPEDevent.LifeCycleRequestEvent TheLifeCycleRequestEventrepresents aLifeCycleRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.LifeCycleRequestObserver An observer for listening toLifeCycleRequestEventinstances.LifeCycleStatusEvent TTheLifeCycleStatusEventindicates theLifeCycleStatusfor a component.LifeCycleStatusObserver An observer for listening toLifeCycleStatusEventinstances.NetworkRequestEvent<CON> TheNetworkRequestEventrepresents aConnectionRequestfor a connection and might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.NetworkStatusEvent<CON> TheNetworkStatusEventindicates theConnectionStatusfor a component's connection.ObservableLifeCycleAutomatonAccessor Provides an accessor for anObservableLifeCycleStatusAutomatonproperty.ObservableLifeCycleAutomatonAccessor.ObservableLifeCycleAutomatonMutator Provides a mutator for anObservableLifeCycleStatusAutomatonproperty.ObservableLifeCycleAutomatonAccessor.ObservableLifeCycleAutomatonProperty Provides anObservableLifeCycleStatusAutomatonproperty.ObservableLifeCycleRequestAutomaton TheObservableLifeCycleRequestAutomatonextends theObservableLifeCycleStatusAutomatonwith requestGenericActionEventfunctionality which can be vetoed.ObservableLifeCycleStatusAutomaton A system implementing this interface supports a component life-cycle. -
Class Summary Class Description AbstractConnectionRequestEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericConnectionRequestEvent.AbstractConnectionStatusEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericConnectionStatusEvent.AbstractLifeCycleRequestEvent<META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericLifeCycleRequestEvent.AbstractLifeCycleStatusEvent<A,META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericLifeCycleStatusEvent.AbstractNetworkRequestEvent<CON,A,META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericNetworkRequestEvent.AbstractNetworkStatusEvent<CON,A,META extends org.refcodes.mixin.EventMetaData,SRC> Abstract implementation of the baseGenericNetworkStatusEvent.ClosedEvent Implementation of theConnectionStatusEventforConnectionStatus.CLOSED.CloseEvent Implementation of theConnectionRequestEventforConnectionRequest.CLOSE.DestroyedEvent Implementation of theLifeCycleStatusEventforLifeCycleStatus.DESTROYED.DestroyEvent Implementation of theLifeCycleRequestEventforLifeCycleRequest.DESTROY.InitializedEvent Implementation of theLifeCycleStatusEventforLifeCycleStatus.INITIALIZED.InitializeEvent Implementation of theLifeCycleRequestEventforLifeCycleRequest.INITIALIZE.ObservableLifeCycleRequestAutomatonImpl Abstract implementation of theObservableLifeCycleStatusAutomatoninterface with the according hook methods for you to create your domain drivenObservableLifeCycleStatusAutomaton.ObservableLifeCycleStatusAutomatonImpl Abstract implementation of theObservableLifeCycleStatusAutomatoninterface with the according hook methods for you to create your domain drivenObservableLifeCycleStatusAutomaton.OpenedEvent Implementation of theConnectionStatusEventforConnectionStatus.OPENED.OpenEvent Implementation of theConnectionRequestEventforConnectionRequest.OPEN.PausedEvent Implementation of theLifeCycleStatusEventforLifeCycleStatus.PAUSED.PauseEvent Implementation of theLifeCycleRequestEventforLifeCycleRequest.PAUSE.ResumedEvent Implementation of theLifeCycleStatusEventforLifeCycleStatus.STARTED.ResumeEvent Implementation of theLifeCycleRequestEventforLifeCycleRequest.RESUME.StartedEvent Implementation of theLifeCycleStatusEventforLifeCycleStatus.STARTED.StartEvent Implementation of theLifeCycleRequestEventforLifeCycleRequest.START.StopEvent Implementation of theLifeCycleRequestEventforLifeCycleRequest.STOP.StoppedEvent Implementation of theLifeCycleStatusEventforLifeCycleStatus.STOPPED.