Uses of Package
org.refcodes.component.ext.observer
-
Classes in org.refcodes.component.ext.observer used by org.refcodes.component.ext.observer Class Description AbstractConnectionRequestEvent Abstract implementation of the baseGenericConnectionRequestEvent.AbstractConnectionStatusEvent Abstract implementation of the baseGenericConnectionStatusEvent.ClosedEvent Implementation of theConnectionStatusEventforConnectionStatus.CLOSED.CloseEvent Implementation of theConnectionRequestEventforConnectionRequest.CLOSE.ConnectionObserver An observer for listening toConnectionStatusEventinstances.ConnectionRequestAccessor Provides an accessor for aConnectionRequestproperty.ConnectionRequestAccessor.ConnectionRequestMutator Provides a mutator for aConnectionRequestproperty.ConnectionRequestEvent TheConnectionRequestEventrepresents aConnectionRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.ConnectionStatusEvent TheConnectionStatusEventindicates theConnectionStatusfor a component.GenericClosedEvent TheGenericClosedEventsignals aConnectionStatus.CLOSEDevent.GenericCloseEvent TheGenericCloseEventsignals aConnectionRequest.CLOSEevent.GenericConnectionRequestEvent TheGenericConnectionRequestEventrepresents aConnectionRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericConnectionStatusEvent TheGenericConnectionStatusEventindicates theConnectionStatusfor a connection.GenericDestroyedEvent TheGenericDestroyedEventsignals aLifecycleStatus.DESTROYEDevent.GenericDestroyEvent TheGenericDestroyEventsignals aLifecycleRequest.DESTROYevent.GenericInitializedEvent TheGenericInitializedEventsignals aLifecycleStatus.INITIALIZEDevent.GenericInitializeEvent TheGenericInitializeEventsignals aLifecycleRequest.INITIALIZEevent.GenericLifecycleRequestEvent TheGenericLifecycleRequestEventrepresents aLifecycleRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericLifecycleRequestObserver TheGenericLifecycleRequestObserveris signaled uponGenericLifecycleRequestEventevents.GenericLifecycleStatusEvent TheGenericLifecycleStatusEventindicates theLifecycleStatusfor a component.GenericLifecycleStatusObserver TheGenericLifecycleStatusObserveris signaled uponGenericLifecycleStatusEventevents.GenericNetworkRequestEvent TheGenericNetworkRequestEventrepresents aConnectionRequestfor a connection and might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericNetworkStatusEvent TheGenericNetworkStatusEventindicates theConnectionStatusfor a component's connection.GenericOpenedEvent TheGenericOpenedEventsignals aConnectionStatus.OPENEDevent.GenericOpenEvent TheGenericOpenEventsignals aConnectionRequest.OPENevent.GenericPausedEvent TheGenericPausedEventsignals aLifecycleStatus.PAUSEDevent.GenericPauseEvent TheGenericPauseEventsignals aLifecycleRequest.PAUSEevent.GenericResumedEvent TheGenericResumedEventsignals aLifecycleStatus.STARTEDevent.GenericResumeEvent TheGenericResumeEventsignals aLifecycleRequest.RESUMEevent.GenericStartedEvent TheGenericStartedEventsignals aLifecycleStatus.STARTEDevent.GenericStartEvent TheGenericStartEventsignals aLifecycleRequest.STARTevent.GenericStopEvent TheGenericStopEventsignals aLifecycleRequest.STOPevent.GenericStoppedEvent TheGenericStoppedEventsignals aLifecycleStatus.STOPPEDevent.LifecycleRequestEvent TheLifecycleRequestEventrepresents aLifecycleRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.LifecycleRequestObserver An observer for listening toLifecycleRequestEventinstances.LifecycleStatusEvent TTheLifecycleStatusEventindicates theLifecycleStatusfor a component.LifecycleStatusObserver An observer for listening toLifecycleStatusEventinstances.ObservableLifecycleAutomatonAccessor Provides an accessor for anObservableLifecycleStatusAutomatonproperty.ObservableLifecycleAutomatonAccessor.ObservableLifecycleAutomatonMutator Provides a mutator for anObservableLifecycleStatusAutomatonproperty.ObservableLifecycleRequestAutomaton TheObservableLifecycleRequestAutomatonextends theObservableLifecycleStatusAutomatonwith requestGenericActionEventfunctionality which can be vetoed.ObservableLifecycleStatusAutomaton A system implementing this interface supports a component life-cycle.OpenedEvent Implementation of theConnectionStatusEventforConnectionStatus.OPENED.OpenEvent Implementation of theConnectionRequestEventforConnectionRequest.OPEN.