Uses of Package
org.refcodes.component.ext.observer
-
Classes in org.refcodes.component.ext.observer used by org.refcodes.component.ext.observer Class Description AbstractConnectionRequestEvent Abstract implementation of the baseGenericConnectionRequestEvent.AbstractConnectionStatusEvent Abstract implementation of the baseGenericConnectionStatusEvent.ClosedEvent Implementation of theConnectionStatusEventforConnectionStatus.CLOSED.CloseEvent Implementation of theConnectionRequestEventforConnectionRequest.CLOSE.ConnectionObserver An observer for listening toConnectionStatusEventinstances.ConnectionRequestAccessor Provides an accessor for aConnectionRequestproperty.ConnectionRequestAccessor.ConnectionRequestMutator Provides a mutator for aConnectionRequestproperty.ConnectionRequestEvent TheConnectionRequestEventrepresents aConnectionRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.ConnectionStatusEvent TheConnectionStatusEventindicates theConnectionStatusfor a component.GenericClosedEvent TheGenericClosedEventsignals aConnectionStatus.CLOSEDevent.GenericCloseEvent TheGenericCloseEventsignals aConnectionRequest.CLOSEevent.GenericConnectionRequestEvent TheGenericConnectionRequestEventrepresents aConnectionRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericConnectionStatusEvent TheGenericConnectionStatusEventindicates theConnectionStatusfor a connection.GenericDestroyedEvent TheGenericDestroyedEventsignals aLifeCycleStatus.DESTROYEDevent.GenericDestroyEvent TheGenericDestroyEventsignals aLifeCycleRequest.DESTROYevent.GenericInitializedEvent TheGenericInitializedEventsignals aLifeCycleStatus.INITIALIZEDevent.GenericInitializeEvent TheGenericInitializeEventsignals aLifeCycleRequest.INITIALIZEevent.GenericLifeCycleRequestEvent TheGenericLifeCycleRequestEventrepresents aLifeCycleRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericLifeCycleRequestObserver TheGenericLifeCycleRequestObserveris signaled uponGenericLifeCycleRequestEventevents.GenericLifeCycleStatusEvent TheGenericLifeCycleStatusEventindicates theLifeCycleStatusfor a component.GenericLifeCycleStatusObserver TheGenericLifeCycleStatusObserveris signaled uponGenericLifeCycleStatusEventevents.GenericNetworkRequestEvent TheGenericNetworkRequestEventrepresents aConnectionRequestfor a connection and might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.GenericNetworkStatusEvent TheGenericNetworkStatusEventindicates theConnectionStatusfor a component's connection.GenericOpenedEvent TheGenericOpenedEventsignals aConnectionStatus.OPENEDevent.GenericOpenEvent TheGenericOpenEventsignals aConnectionRequest.OPENevent.GenericPausedEvent TheGenericPausedEventsignals aLifeCycleStatus.PAUSEDevent.GenericPauseEvent TheGenericPauseEventsignals aLifeCycleRequest.PAUSEevent.GenericResumedEvent TheGenericResumedEventsignals aLifeCycleStatus.STARTEDevent.GenericResumeEvent TheGenericResumeEventsignals aLifeCycleRequest.RESUMEevent.GenericStartedEvent TheGenericStartedEventsignals aLifeCycleStatus.STARTEDevent.GenericStartEvent TheGenericStartEventsignals aLifeCycleRequest.STARTevent.GenericStopEvent TheGenericStopEventsignals aLifeCycleRequest.STOPevent.GenericStoppedEvent TheGenericStoppedEventsignals aLifeCycleStatus.STOPPEDevent.LifeCycleRequestEvent TheLifeCycleRequestEventrepresents aLifeCycleRequestand might be vetoed by (depending on the firing observable) throwing aVetoExceptionorVetoException.VetoRuntimeExceptionby the accordingObserver.LifeCycleRequestObserver An observer for listening toLifeCycleRequestEventinstances.LifeCycleStatusEvent TTheLifeCycleStatusEventindicates theLifeCycleStatusfor a component.LifeCycleStatusObserver An observer for listening toLifeCycleStatusEventinstances.ObservableLifeCycleAutomatonAccessor Provides an accessor for anObservableLifeCycleStatusAutomatonproperty.ObservableLifeCycleAutomatonAccessor.ObservableLifeCycleAutomatonMutator Provides a mutator for anObservableLifeCycleStatusAutomatonproperty.ObservableLifeCycleRequestAutomaton TheObservableLifeCycleRequestAutomatonextends theObservableLifeCycleStatusAutomatonwith requestGenericActionEventfunctionality which can be vetoed.ObservableLifeCycleStatusAutomaton A system implementing this interface supports a component life-cycle.OpenedEvent Implementation of theConnectionStatusEventforConnectionStatus.OPENED.OpenEvent Implementation of theConnectionRequestEventforConnectionRequest.OPEN.